/*
 * Copyright (c) 2011, Stefan Götz <stefan.goetz@web.de>
 * 
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
 * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

/**
 * @file
 * Helpers for handling differences in languages, compilers, and platforms.
 */

#undef C_DECLARATIONS_START
#undef C_DECLARATIONS_END
#ifdef __cplusplus
/**
 * Allow C code to be used in C++ environments (see http://www.parashift.com/c++-faq-lite/mixing-c-and-cpp.html).
 * This macro must be present in public header files before the first C function declaration.
 */
#define C_DECLARATIONS_START extern "C" {
/**
 * This macro must be present in public header files after the last C function declaration.
 */
#define C_DECLARATIONS_END   }
#else
#define C_DECLARATIONS_START
#define C_DECLARATIONS_END
#endif

#undef ARGS
#if defined (__STDC__) || defined (_AIX) || defined (__mips) || defined (_SYSTYPE_SVR4) || defined (WIN32) || defined (__cplusplus) || defined (DOXYGEN)
/**
 * Allow non-ANSI compilers to compile ANSI-style function declarations with arguments.
 * For every public C function declaration, this macro must wrap the function arguments including the parentheses.
 * For example:
 * @code int ansi_declared_function ARGS((const int x, long y)); @endcode
 */
#define ARGS(args) args
#else
#define ARGS(args) ()
#endif
